Crate clip_qdrant
source ·Re-exports
pub use db::Db;
Modules
Macros
Structs
- A value that is initialized on the first access. The initialization procedure is allowed to be asycnhronous, so access to the value requires an
await.
pub use db::Db;await.